..  image:: https://raw.githubusercontent.com/ricequant/rqalpha/master/docs/source/_static/logo.jpg

===============================
RQAlpha
===============================

..  image:: https://img.shields.io/travis/ricequant/rqalpha/master.svg
    :target: https://travis-ci.org/ricequant/rqalpha/branches
    :alt: Build

..  image:: https://coveralls.io/repos/github/ricequant/rqalpha/badge.svg?branch=master
    :target: https://coveralls.io/github/ricequant/rqalpha?branch=master

..  image:: https://readthedocs.org/projects/rqalpha/badge/?version=stable
    :target: http://rqalpha.readthedocs.io/zh_CN/stable/?badge=stable
    :alt: Documentation Status

..  image:: https://img.shields.io/pypi/v/rqalpha.svg
    :target: https://pypi.python.org/pypi/rqalpha
    :alt: PyPI Version

..  image:: https://img.shields.io/pypi/l/rqalpha.svg
    :target: https://opensource.org/licenses/Apache-2.0
    :alt: License

..  image:: https://img.shields.io/pypi/pyversions/rqalpha.svg
    :target: https://pypi.python.org/pypi/rqalpha
    :alt: Python Version Support


RQAlpha 从数据获取、算法交易、回测引擎，实盘模拟，实盘交易到数据分析，为程序化交易者提供了全套解决方案。RQAlpha 具有灵活的配置方式，强大的扩展性，用户可以非常容易地定制专属于自己的程序化交易系统。

RQAlpha 所有的策略都可以直接在 `Ricequant`_ 上进行回测和实盘模拟，并且可以通过微信和邮件实时推送您的交易信号。

`Ricequant`_ 是一个开放的量化算法交易社区，为程序化交易者提供免费的回测和实盘模拟环境，并且会不间断举行实盘资金投入的量化比赛。

Feature
============================

*   易于使用: RQAlpha让您集中于策略的开发，一行简单的命令就可以执行您的策略。
*   完善的文档: 您可以直接访问 `RQAlpha 文档`_ 或者 `Ricequant 文档`_ 来获取您需要的信息。
*   活跃的社区: 您可以通过访问 `Ricequant 社区`_ 获取和询问有关 RQAlpha 的一切问题，有很多优秀的童鞋会解答您的问题。
*   稳定的环境: 每天都有会大量的算法交易在 Ricequant 上运行，无论是 RQAlpha，还是数据，我们能会做到问题秒处理，秒解决。
*   灵活的配置: RQAlpha 提供了一系列的配置选项，用户可以通过简单的配置来构建适合自己的交易系统。
*   强大的扩展性: RQAlpha 定义了一系列的 Mod Hook 接口，开发者可以基于 Mod 的开发模式，扩展 RQAlpha，无论是做实时监控，还是归因分析，RQAlpha 都可以通过扩展来实现。

Getting Help
============================

关于RQAlpha的任何问题可以通过以下途径来获取帮助

*  查看 `FAQ`_ 页面找寻常见问题及解答。
*  可以通过 `索引`_ 或者 `搜索`_ 来查找特定问题。
*  在 `Github Issue`_ 中提交issue。
*  如果想参与到 RQAlpha 的开发中，您可以加入QQ群「487188429」，

Quick Guide
============================

*   `RQAlpha 介绍`_
*   `安装指南`_
*   `10分钟学会 RQAlpha`_
*   `策略示例`_

RQAlpha API
============================

*   `参数配置`_ : 启动 RQAlpha 参数配置
*   `API`_ : RQAlpha API 文档

Development
============================

*   `How To Contribute`_ : 如何加入 RQAlpha 的开发
*   `Basic Concept`_ : 基本概念
*   `RQAlpha Mod`_ : 基于Mod来开发和扩展RQAlpha

Extra
============================

*   `FAQ`_
*   `History`_


.. _Github Issue: https://github.com/ricequant/rqalpha/issues
.. _Ricequant: https://www.ricequant.com/algorithms
.. _RQAlpha 文档: http://rqalpha.readthedocs.io/zh_CN/stable/
.. _Ricequant 文档: https://www.ricequant.com/api/python/chn
.. _Ricequant 社区: https://www.ricequant.com/community/category/all/
.. _FAQ: http://rqalpha.readthedocs.io/zh_CN/stable/faq.html
.. _索引: http://rqalpha.readthedocs.io/zh_CN/stable/genindex.html

.. _RQAlpha 介绍: http://rqalpha.readthedocs.io/zh_CN/stable/intro/overview.html
.. _安装指南: http://rqalpha.readthedocs.io/zh_CN/stable/intro/install.html
.. _10分钟学会 RQAlpha: http://rqalpha.readthedocs.io/zh_CN/stable/intro/tutorial.html
.. _策略示例: http://rqalpha.readthedocs.io/zh_CN/stable/intro/examples.html

.. _参数配置: http://rqalpha.readthedocs.io/zh_CN/stable/api/config.html
.. _API: http://rqalpha.readthedocs.io/zh_CN/stable/api/base_api.html

.. _How To Contribute: http://rqalpha.readthedocs.io/zh_CN/stable/development/make_contribute.html
.. _Basic Concept: http://rqalpha.readthedocs.io/zh_CN/stable/development/basic_concept.html
.. _RQAlpha Mod: http://rqalpha.readthedocs.io/zh_CN/stable/development/mod.html
.. _History: http://rqalpha.readthedocs.io/zh_CN/stable/history.html
